@@ -1,7 +1,7 @@
 package Log::ger;
 
 our $DATE = '2018-12-20'; # DATE
-our $VERSION = '0.024'; # VERSION
+our $VERSION = '0.025'; # VERSION
 
 #IFUNBUILT
 # use strict;
@@ -166,7 +166,7 @@ Log::ger - A lightweight, flexible logging framework
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 SYNOPSIS
 
@@ -213,14 +213,21 @@ provided in separate distributions to be pulled as needed.
 B<Low startup overhead.> Only ~0.5-1ms. For comparison, L<strict> ~0.2-0.5ms,
 L<warnings> ~2ms, L<Log::Any> 0.15 ~2-3ms, Log::Any 1.049 ~8-10ms,
 L<Log::Log4perl> ~35ms. This is measured on a 2014-2015 PC and before doing any
-output configuration. For more benchmarks, see L<Bencher::Scenarios::LogGer> or
-try yourself e.g. with L<bencher-code>:
+output configuration. I strive to make C<use Log::ger;> statement to be roughly
+as light as C<use strict;> or C<use warnings;> so the impact of adding the
+statement is really minimal and you can just add logging without much thought to
+most of your modules. This is important to me because I want logging to be
+pervasive.
+
+To test for yourself, try e.g. with L<bencher-code>:
 
  % bencher-code 'use Log::ger' 'use Log::Any' --startup
 
 B<Fast>. Low null-/stealth-logging overhead, about 1.5x faster than Log::Any, 3x
-faster than Log4perl, 5x faster than L<Log::Fast>, and ~100x faster than
-L<Log::Dispatch>.
+faster than Log4perl, 5x faster than L<Log::Fast>, ~40x faster than
+L<Log::Contextual>, and ~100x faster than L<Log::Dispatch>.
+
+For more benchmarks, see L<Bencher::Scenarios::LogGer>.
 
 B<Conditional compilation.> There is a plugin to optimize away unneeded logging
 statements, like assertion/conditional compilation, so they have zero runtime
@@ -267,6 +274,9 @@ For more documentation, start with L<Log::ger::Manual>.
 Some other popular logging frameworks: L<Log::Any>, L<Log::Contextual>,
 L<Log::Log4perl>, L<Log::Dispatch>, L<Log::Dispatchouli>.
 
+If you still prefer debugging using the good old C<print()>, there's
+L<Debug::Print>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
